==> ghc5_5.02.2.orig.tar.gz: ghc5-5.02.2.orig/hslibs/win32/Win32Bitmap_stub_ffi.h <==
#include "HsFFI.h"
extern unsigned int prim_sRCCOPY();
extern unsigned int prim_sRCPAINT();
extern unsigned int prim_sRCAND();
extern unsigned int prim_sRCINVERT();
extern unsigned int prim_sRCERASE();
extern unsigned int prim_nOTSRCCOPY();
extern unsigned int prim_nOTSRCERASE();
extern unsigned int prim_mERGECOPY();
extern unsigned int prim_mERGEPAINT();
extern unsigned int prim_pATCOPY();
extern unsigned int prim_pATPAINT();
extern unsigned int prim_pATINVERT();
extern unsigned int prim_dSTINVERT();
extern unsigned int prim_bLACKNESS();
extern unsigned int prim_wHITENESS();
extern unsigned int prim_mAKEROP4(unsigned int arg1,unsigned int arg2);
extern void prim_setBITMAP(BITMAP * arg1,LONG gc_arg3,LONG gc_arg5,LONG gc_arg7,LONG gc_arg9,WORD gc_arg11,WORD gc_arg13,LPVOID gc_arg14);
extern void* prim_deleteBitmap(HBITMAP arg1);
extern int access_prim_deleteBitmap_gc_failed(HsPtr);
extern void* access_prim_deleteBitmap_gc_failstring(HsPtr);
extern void* prim_createCompatibleBitmap(HDC arg1,int arg2,int arg3);
extern HBITMAP access_prim_createCompatibleBitmap_res1(HsPtr);
extern int access_prim_createCompatibleBitmap_gc_failed(HsPtr);
extern void* access_prim_createCompatibleBitmap_gc_failstring(HsPtr);
extern void* prim_createBitmap(INT arg1,INT arg2,UINT arg3,UINT arg4,LPVOID arg5);
extern HBITMAP access_prim_createBitmap_res1(HsPtr);
extern int access_prim_createBitmap_gc_failed(HsPtr);
extern void* access_prim_createBitmap_gc_failstring(HsPtr);
extern void* prim_createBitmapIndirect(BITMAP * arg1);
extern HBITMAP access_prim_createBitmapIndirect_res1(HsPtr);
extern int access_prim_createBitmapIndirect_gc_failed(HsPtr);
extern void* access_prim_createBitmapIndirect_gc_failstring(HsPtr);
extern void* prim_createDIBPatternBrushPt(LPVOID arg1,DWORD arg2);
extern HBRUSH access_prim_createDIBPatternBrushPt_res1(HsPtr);
extern int access_prim_createDIBPatternBrushPt_gc_failed(HsPtr);
extern void* access_prim_createDIBPatternBrushPt_gc_failstring(HsPtr);
extern void* prim_getBitmapDimensionEx(HBITMAP h);
extern LONG access_prim_getBitmapDimensionEx_gc_res2(HsPtr);
extern LONG access_prim_getBitmapDimensionEx_gc_res4(HsPtr);
extern int access_prim_getBitmapDimensionEx_gc_failed(HsPtr);
extern void* access_prim_getBitmapDimensionEx_gc_failstring(HsPtr);
extern void* prim_setBitmapDimensionEx(HBITMAP h,LONG gc_arg3,LONG gc_arg5);
extern LONG access_prim_setBitmapDimensionEx_gc_res2(HsPtr);
extern LONG access_prim_setBitmapDimensionEx_gc_res4(HsPtr);
extern int access_prim_setBitmapDimensionEx_gc_failed(HsPtr);
extern void* access_prim_setBitmapDimensionEx_gc_failstring(HsPtr);
extern void* prim_getBitmapInfo(HBITMAP x);
extern LONG access_prim_getBitmapInfo_gc_res2(HsPtr);
extern LONG access_prim_getBitmapInfo_gc_res4(HsPtr);
extern LONG access_prim_getBitmapInfo_gc_res6(HsPtr);
extern LONG access_prim_getBitmapInfo_gc_res8(HsPtr);
extern WORD access_prim_getBitmapInfo_gc_res10(HsPtr);
extern WORD access_prim_getBitmapInfo_gc_res12(HsPtr);
extern LPVOID access_prim_getBitmapInfo_gc_res13(HsPtr);
extern int access_prim_getBitmapInfo_gc_failed(HsPtr);
extern void* access_prim_getBitmapInfo_gc_failstring(HsPtr);
extern WORD prim_bI_RGB();
extern WORD prim_bI_RLE8();
extern WORD prim_bI_RLE4();
extern WORD prim_bI_BITFIELDS();
extern DWORD prim_dIB_PAL_COLORS();
extern DWORD prim_dIB_RGB_COLORS();
extern void* prim_getBITMAPINFOHEADER_(BITMAPINFOHEADER * arg1);
extern DWORD access_prim_getBITMAPINFOHEADER__gc_res1(HsPtr);
extern LONG access_prim_getBITMAPINFOHEADER__gc_res3(HsPtr);
extern LONG access_prim_getBITMAPINFOHEADER__gc_res5(HsPtr);
extern WORD access_prim_getBITMAPINFOHEADER__gc_res7(HsPtr);
extern WORD access_prim_getBITMAPINFOHEADER__gc_res9(HsPtr);
extern WORD access_prim_getBITMAPINFOHEADER__gc_res11(HsPtr);
extern DWORD access_prim_getBITMAPINFOHEADER__gc_res12(HsPtr);
extern LONG access_prim_getBITMAPINFOHEADER__gc_res14(HsPtr);
extern LONG access_prim_getBITMAPINFOHEADER__gc_res16(HsPtr);
extern DWORD access_prim_getBITMAPINFOHEADER__gc_res18(HsPtr);
extern DWORD access_prim_getBITMAPINFOHEADER__gc_res20(HsPtr);
extern void* prim_getBITMAPFILEHEADER(BITMAPFILEHEADER * arg1);
extern WORD access_prim_getBITMAPFILEHEADER_gc_res2(HsPtr);
extern DWORD access_prim_getBITMAPFILEHEADER_gc_res3(HsPtr);
extern WORD access_prim_getBITMAPFILEHEADER_gc_res5(HsPtr);
extern WORD access_prim_getBITMAPFILEHEADER_gc_res7(HsPtr);
extern DWORD access_prim_getBITMAPFILEHEADER_gc_res8(HsPtr);
extern unsigned int prim_sizeofBITMAP();
extern unsigned int prim_sizeofBITMAPINFO();
extern unsigned int prim_sizeofBITMAPINFOHEADER();
extern unsigned int prim_sizeofBITMAPFILEHEADER();
extern unsigned int prim_sizeofLPBITMAPFILEHEADER();
extern void prim_createBMPFile(char * arg1,HBITMAP arg2,HDC arg3);
extern DWORD prim_cBM_INIT();
extern void* prim_getDIBits(HDC arg1,HBITMAP arg2,INT arg3,INT arg4,LPVOID arg5,BITMAPINFO * arg6,DWORD arg7);
extern INT access_prim_getDIBits_res1(HsPtr);
extern int access_prim_getDIBits_gc_failed(HsPtr);
extern void* access_prim_getDIBits_gc_failstring(HsPtr);
extern void* prim_setDIBits(HDC arg1,HBITMAP arg2,INT arg3,INT arg4,LPVOID arg5,BITMAPINFO * arg6,DWORD arg7);
extern INT access_prim_setDIBits_res1(HsPtr);
extern int access_prim_setDIBits_gc_failed(HsPtr);
extern void* access_prim_setDIBits_gc_failstring(HsPtr);
extern void* prim_createDIBitmap(HDC arg1,BITMAPINFOHEADER * arg2,DWORD arg3,LPVOID arg4,BITMAPINFO * arg5,DWORD arg6);
extern HBITMAP access_prim_createDIBitmap_res1(HsPtr);
extern int access_prim_createDIBitmap_gc_failed(HsPtr);
extern void* access_prim_createDIBitmap_gc_failstring(HsPtr);

==> ghc6_6.2.2.orig.tar.gz: ghc6-6.2.2/hslibs/win32/Win32Bitmap_stub_ffi.h <==
#include "Win32Aux.h"
#include <windows.h>
#include "errors.h"
#include "win32debug.h"
#include "finalizers.h"
#include "dumpBMP.h"
#include "HsFFI.h"
extern unsigned int prim_sRCCOPY();
extern unsigned int prim_sRCPAINT();
extern unsigned int prim_sRCAND();
extern unsigned int prim_sRCINVERT();
extern unsigned int prim_sRCERASE();
extern unsigned int prim_nOTSRCCOPY();
extern unsigned int prim_nOTSRCERASE();
extern unsigned int prim_mERGECOPY();
extern unsigned int prim_mERGEPAINT();
extern unsigned int prim_pATCOPY();
extern unsigned int prim_pATPAINT();
extern unsigned int prim_pATINVERT();
extern unsigned int prim_dSTINVERT();
extern unsigned int prim_bLACKNESS();
extern unsigned int prim_wHITENESS();
extern unsigned int prim_mAKEROP4(unsigned int arg1,unsigned int arg2);
extern void prim_setBITMAP(BITMAP * arg1,LONG gc_arg2,LONG gc_arg3,LONG gc_arg4,LONG gc_arg5,WORD gc_arg6,WORD gc_arg7,LPVOID gc_arg8);
extern void* prim_deleteBitmap(HBITMAP arg1);
extern int access_prim_deleteBitmap_gc_failed(HsPtr);
extern void* access_prim_deleteBitmap_gc_failstring(HsPtr);
extern void* prim_createCompatibleBitmap(HDC arg1,int arg2,int arg3);
extern HBITMAP access_prim_createCompatibleBitmap_res1(HsPtr);
extern int access_prim_createCompatibleBitmap_gc_failed(HsPtr);
extern void* access_prim_createCompatibleBitmap_gc_failstring(HsPtr);
extern void* prim_createBitmap(INT arg1,INT arg2,UINT arg3,UINT arg4,LPVOID arg5);
extern HBITMAP access_prim_createBitmap_res1(HsPtr);
extern int access_prim_createBitmap_gc_failed(HsPtr);
extern void* access_prim_createBitmap_gc_failstring(HsPtr);
extern void* prim_createBitmapIndirect(BITMAP * arg1);
extern HBITMAP access_prim_createBitmapIndirect_res1(HsPtr);
extern int access_prim_createBitmapIndirect_gc_failed(HsPtr);
extern void* access_prim_createBitmapIndirect_gc_failstring(HsPtr);
extern void* prim_createDIBPatternBrushPt(LPVOID arg1,DWORD arg2);
extern HBRUSH access_prim_createDIBPatternBrushPt_res1(HsPtr);
extern int access_prim_createDIBPatternBrushPt_gc_failed(HsPtr);
extern void* access_prim_createDIBPatternBrushPt_gc_failstring(HsPtr);
extern void* prim_getBitmapDimensionEx(HBITMAP h);
extern LONG access_prim_getBitmapDimensionEx_gc_res1(HsPtr);
extern LONG access_prim_getBitmapDimensionEx_gc_res2(HsPtr);
extern int access_prim_getBitmapDimensionEx_gc_failed(HsPtr);
extern void* access_prim_getBitmapDimensionEx_gc_failstring(HsPtr);
extern void* prim_setBitmapDimensionEx(HBITMAP h,LONG gc_arg2,LONG gc_arg3);
extern LONG access_prim_setBitmapDimensionEx_gc_res1(HsPtr);
extern LONG access_prim_setBitmapDimensionEx_gc_res2(HsPtr);
extern int access_prim_setBitmapDimensionEx_gc_failed(HsPtr);
extern void* access_prim_setBitmapDimensionEx_gc_failstring(HsPtr);
extern void* prim_getBitmapInfo(HBITMAP x);
extern LONG access_prim_getBitmapInfo_gc_res1(HsPtr);
extern LONG access_prim_getBitmapInfo_gc_res2(HsPtr);
extern LONG access_prim_getBitmapInfo_gc_res3(HsPtr);
extern LONG access_prim_getBitmapInfo_gc_res4(HsPtr);
extern WORD access_prim_getBitmapInfo_gc_res5(HsPtr);
extern WORD access_prim_getBitmapInfo_gc_res6(HsPtr);
extern LPVOID access_prim_getBitmapInfo_gc_res7(HsPtr);
extern int access_prim_getBitmapInfo_gc_failed(HsPtr);
extern void* access_prim_getBitmapInfo_gc_failstring(HsPtr);
extern WORD prim_bI_RGB();
extern WORD prim_bI_RLE8();
extern WORD prim_bI_RLE4();
extern WORD prim_bI_BITFIELDS();
extern DWORD prim_dIB_PAL_COLORS();
extern DWORD prim_dIB_RGB_COLORS();
extern void* prim_getBITMAPINFOHEADER_(BITMAPINFOHEADER * arg1);
extern DWORD access_prim_getBITMAPINFOHEADER__gc_res1(HsPtr);
extern LONG access_prim_getBITMAPINFOHEADER__gc_res2(HsPtr);
extern LONG access_prim_getBITMAPINFOHEADER__gc_res3(HsPtr);
extern WORD access_prim_getBITMAPINFOHEADER__gc_res4(HsPtr);
extern WORD access_prim_getBITMAPINFOHEADER__gc_res5(HsPtr);
extern WORD access_prim_getBITMAPINFOHEADER__gc_res6(HsPtr);
extern DWORD access_prim_getBITMAPINFOHEADER__gc_res7(HsPtr);
extern LONG access_prim_getBITMAPINFOHEADER__gc_res8(HsPtr);
extern LONG access_prim_getBITMAPINFOHEADER__gc_res9(HsPtr);
extern DWORD access_prim_getBITMAPINFOHEADER__gc_res11(HsPtr);
extern DWORD access_prim_getBITMAPINFOHEADER__gc_res13(HsPtr);
extern void* prim_getBITMAPFILEHEADER(BITMAPFILEHEADER * arg1);
extern WORD access_prim_getBITMAPFILEHEADER_gc_res1(HsPtr);
extern DWORD access_prim_getBITMAPFILEHEADER_gc_res2(HsPtr);
extern WORD access_prim_getBITMAPFILEHEADER_gc_res3(HsPtr);
extern WORD access_prim_getBITMAPFILEHEADER_gc_res4(HsPtr);
extern DWORD access_prim_getBITMAPFILEHEADER_gc_res5(HsPtr);
extern unsigned int prim_sizeofBITMAP();
extern unsigned int prim_sizeofBITMAPINFO();
extern unsigned int prim_sizeofBITMAPINFOHEADER();
extern unsigned int prim_sizeofBITMAPFILEHEADER();
extern unsigned int prim_sizeofLPBITMAPFILEHEADER();
extern void prim_createBMPFile(char * arg1,HBITMAP arg2,HDC arg3);
extern DWORD prim_cBM_INIT();
extern void* prim_getDIBits(HDC arg1,HBITMAP arg2,INT arg3,INT arg4,LPVOID arg5,BITMAPINFO * arg6,DWORD arg7);
extern INT access_prim_getDIBits_res1(HsPtr);
extern int access_prim_getDIBits_gc_failed(HsPtr);
extern void* access_prim_getDIBits_gc_failstring(HsPtr);
extern void* prim_setDIBits(HDC arg1,HBITMAP arg2,INT arg3,INT arg4,LPVOID arg5,BITMAPINFO * arg6,DWORD arg7);
extern INT access_prim_setDIBits_res1(HsPtr);
extern int access_prim_setDIBits_gc_failed(HsPtr);
extern void* access_prim_setDIBits_gc_failstring(HsPtr);
extern void* prim_createDIBitmap(HDC arg1,BITMAPINFOHEADER * arg2,DWORD arg3,LPVOID arg4,BITMAPINFO * arg5,DWORD arg6);
extern HBITMAP access_prim_createDIBitmap_res1(HsPtr);
extern int access_prim_createDIBitmap_gc_failed(HsPtr);
extern void* access_prim_createDIBitmap_gc_failstring(HsPtr);
